@@ -2,7 +2,7 @@
  *                   Materials Object Library                  *
  * Class isotropic_tensor : declaration for isotropic material *
  *                    simula+@metz.ensam.fr                    *
- *                   GNU/linux version 2.2.0                   *
+ *                   GNU/linux version 2.4.0                   *
  *            software under General Public License            *
  ***************************************************************
  * copyright © 2002,2003,2004,2005,2006,2007,2008,2009 COLLARD Christophe
@@ -48,8 +48,8 @@
             copyright \htmlonly &#169; \endhtmlonly 2006 Cristelle PARGUEZ \n
             copyright \htmlonly &#169; 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009 Laboratoire de Physique et M&#233;canique des Mat&#233;riaux (LPMM - CNRS) \endhtmlonly \n
 	    copyright \htmlonly &#169; 2002, 2003, 2004, 2005, 2006, 2007 Laboratoire de Math&#233;matiques et ses Applications de Valenciennes (LAMAV) \endhtmlonly
-    \version 2.2.0
-    \date 2002-2009
+    \version 2.4.0
+    \date 2002-2010
     \bug none
     \warning none
 */
@@ -170,7 +170,7 @@ template <class T> class isotropic_tensor
     template <class Tf> friend bool operator != (const isotropic_tensor<Tf>&, const tensor4<Tf>&);
     template <class Tf> friend bool operator != (const tensor4<Tf>&, const isotropic_tensor<Tf>&);
 
-    isotropic_tensor<T> inv ();
+    isotropic_tensor<T> inv () const;
     template <class Tf> friend isotropic_tensor<Tf> change_basis (const matrix<Tf>&, const isotropic_tensor<Tf>&, bool); // for orthogonal matrix
     template <class Tf> friend tensor4<Tf> change_basis (const matrix<Tf>&, const isotropic_tensor<Tf>&);
 
@@ -1187,9 +1187,9 @@ template <class Tf> bool operator != (const tensor4<Tf>& t, const isotropic_tens
   \return inverse tensor
 */
 
-//----------------------------------------------------------------
-template <class T> isotropic_tensor<T> isotropic_tensor<T>::inv ()
-//----------------------------------------------------------------
+//----------------------------------------------------------------------
+template <class T> isotropic_tensor<T> isotropic_tensor<T>::inv () const
+//----------------------------------------------------------------------
 {
   assert (Mu);
   assert (abs(1.5*Lambda + Mu) > epsilon);
