@@ -1,6 +1,6 @@
 /***************************************************************
  *                    simula+@metz.ensam.fr                    *
- *	             GNU/linux version 2.2.0                   *
+ *	             GNU/linux version 2.4.0                   *
  *            software under General Public License            *
  ***************************************************************
  * copyright © 2005,2006,2007,2008,2009 COLLARD Christophe
@@ -93,6 +93,13 @@ int test_Eshelby (int detail)
   int result=1;
   bool test = true;
 
+  if (detail < 0) 
+    { cout << "============================================================== \n";
+      cout << blue << "                     Eshelby test skipped" << reset;
+      cout << "============================================================== \n";
+      return result;
+    }
+
   long double R = 5;
   long double V = 4/3. * pi() * power(R,3);
   long double nu = 0.3;
