@@ -1,6 +1,6 @@
 /***************************************************************
  *                    simula+@metz.ensam.fr                    *
- *	             GNU/linux version 2.2.0                   *
+ *	             GNU/linux version 2.4.0                   *
  *            software under General Public License            *
  ***************************************************************
  * copyright © 2006,2007,2008,2009 COLLARD Christophe
@@ -88,6 +88,13 @@ int test_cubic_tensor (int detail)
 {
   bool result = true;
 
+  if (detail < 0) 
+    { cout << "============================================================== \n";
+      cout << blue << "                   cubic tensor test skipped" << reset;
+      cout << "============================================================== \n";
+      return result;
+    }
+
   long double lambda=60000, mu=40000;
   isotropic_elasticity_tensor<long double> C;
   C.Lame(lambda);
