@@ -1,6 +1,6 @@
 /***************************************************************
  *                    simula+@metz.ensam.fr                    *
- *	             GNU/linux version 2.2.0                   *
+ *	             GNU/linux version 2.4.0                   *
  *            software under General Public License            *
  ***************************************************************
  * copyright © 2003,2004,2005,2006,2007,2008,2009 COLLARD Christophe
@@ -72,6 +72,13 @@ int test_isotropic_elasticity_tensor (int detail)
 {
   bool result = true;
 
+  if (detail < 0) 
+    { cout << "============================================================== \n";
+      cout << blue << "            isotropic elasticity tensor test skipped" << reset;
+      cout << "============================================================== \n";
+      return result;
+    }
+
   long double eps = epsilon;
   epsilon = 1.e-10; // change precision level for computations
 
