@@ -1,6 +1,6 @@
 /***************************************************************
  *                    simula+@metz.ensam.fr                    *
- *	             GNU/linux version 2.2.0                   *
+ *	             GNU/linux version 2.4.0                   *
  *            software under General Public License            *
  ***************************************************************
  * copyright © 2003,2004,2005,2006,2007,2008,2009 COLLARD Christophe
@@ -85,6 +85,13 @@ int test_isotropic_tensor (int detail)
 {
   bool result = true;
 
+  if (detail < 0) 
+    { cout << "============================================================== \n";
+      cout << blue << "                 isotropic tensor test skipped" << reset;
+      cout << "============================================================== \n";
+      return result;
+    }
+
   long double lambda=60000, mu=40000;
   isotropic_tensor<long double> C("elasticity tensor"), S, C0(lambda,mu), C1, C2, Cx, Cxx;
   C.lambda(lambda);
