@@ -1,6 +1,6 @@
 /***************************************************************
  *                    simula+@metz.ensam.fr                    *
- *	             GNU/linux version 2.2.0                   *
+ *	             GNU/linux version 2.4.0                   *
  *            software under General Public License            *
  ***************************************************************
  * copyright © 2005,2006,2007,2008,2009 COLLARD Christophe
@@ -97,7 +97,7 @@
 #endif
 
 //#if !defined(__TIJ_TEST_H)
-//#include"../materials/TIJ-test.h"
+//#include"materials/TIJ-test.h"
 //#endif
 
 #if !defined(__ESHELBY_TEST_H)
@@ -136,7 +136,7 @@ main()
 
   detail = 0;
   start_main = start = clock();
-  if (detail)
+  if (detail>0)
     //=======================================================================
     cout<< "-----------------------isotropic tensor---------------------- \n";
     //=======================================================================
@@ -148,7 +148,7 @@ main()
 
   detail = 0;
   start = clock();
-  if (detail)
+  if (detail>0)
     //=======================================================================
     cout<< "-----------------isotropic elasticity tensor----------------- \n";
     //=======================================================================
@@ -160,7 +160,7 @@ main()
 
   detail = 0;
   start = clock();
-  if (detail)
+  if (detail>0)
     //=======================================================================
     cout<< "------------------------cubic tensor------------------------- \n";
     //=======================================================================
@@ -172,7 +172,7 @@ main()
 
   detail = 0;
   start = clock();
-  if (detail)
+  if (detail>0)
     //=======================================================================
     cout<< "-------------------cubic elasticity tensor------------------- \n";
     //=======================================================================
@@ -184,7 +184,7 @@ main()
 
   detail = 0;
   start = clock();
-  if (detail)
+  if (detail>0)
     //=======================================================================
     cout<< "----------------------orthotropic tensor----------------------\n";
     //=======================================================================
@@ -195,8 +195,8 @@ main()
   cout << endl;
 
   detail = 0;
-  start_main = start = clock();
-  if (detail)
+  start = clock();
+  if (detail>0)
     //=======================================================================
     cout<< "----------------transversely isotropic tensor---------------- \n";
     //=======================================================================
@@ -207,8 +207,8 @@ main()
   cout << endl;
 
   detail = 0;
-  start_main = start = clock();
-  if (detail)
+  start = clock();
+  if (detail>0)
     //=======================================================================
     cout<< "------------transversely isotropic elastic tensor------------ \n";
     //=======================================================================
@@ -220,7 +220,7 @@ main()
 
   detail = 0;
   start = clock();
-  if (detail)
+  if (detail>0)
     //=======================================================================
     cout<< "-----------------------------TII----------------------------- \n";
     //=======================================================================
@@ -232,7 +232,7 @@ main()
 
   detail = 0;
   start = clock();
-  if (detail)
+  if (detail>0)
     //=======================================================================
     cout<< "-----------------------------PII----------------------------- \n";
     //=======================================================================
@@ -258,7 +258,7 @@ main()
 
   detail = 0;
   start = clock();
-  if (detail)
+  if (detail>0)
     //=======================================================================
     cout<< "---------------------------Eshelby--------------------------- \n";
     //=======================================================================
@@ -270,7 +270,7 @@ main()
 
   detail = 0;
   start = clock();
-  if (detail)
+  if (detail>0)
     //=======================================================================
     cout<< "------------------------Schmid tensor------------------------ \n";
     //=======================================================================
@@ -281,8 +281,8 @@ main()
   cout << endl;
 
   detail = 0;
-  start_main = start = clock();
-  if (detail)
+  start = clock();
+  if (detail>0)
     //=======================================================================
     cout<< "---------------------------systems--------------------------- \n";
     //=======================================================================
@@ -293,8 +293,8 @@ main()
   cout << endl;
 
   detail = 0;
-  start_main = start = clock();
-  if (detail)
+  start = clock();
+  if (detail>0)
     //=======================================================================
     cout<< "---------------------------loading--------------------------- \n";
     //=======================================================================
@@ -306,7 +306,7 @@ main()
 
   detail = 0;
   start = clock();
-  if (detail)
+  if (detail>0)
     //=======================================================================
     cout<< "--------------------------MatOolbox-------------------------- \n";
     //=======================================================================
@@ -318,7 +318,7 @@ main()
 
   detail = 0;
   start = clock();
-  if (detail)
+  if (detail>0)
     //=======================================================================
     cout<< "---------------------------walpole--------------------------- \n";
     //=======================================================================
@@ -330,17 +330,6 @@ main()
 
   end_main = clock();
 
-  bool test = true;
-  ifstream file("../simula+.log", ios::in);
-  if (!file.fail())
-    file >> test;
-  file.close();
-  test *= result;
-  ofstream file2("../simula+.log", ios::out);
-  assert (!file2.fail());
-  file2 << test;
-  file2.close();
-
   cout << "============================================================== \n";
   if (result) cout << green << "-------OK-----------end of MateriOL++ tests-----------OK------" << reset;
   else cout << red << "-----FAILED---------end of MateriOL++ tests---------FAILED----" << reset;
